# Error in Calculated Heat of Formation (kcal/mol) Predictions

Dataset: [PDDG](https://doi.org/10.1002/jcc.10162)

### Mean Average Error ± 95% CI
- diff_API_MopacInput: 0.04 ± 0.03

- API_error: 3.50 ± 0.36

- MopacInput_error: 3.50 ± 0.36

reference Error: 3.34, [source](http://pubs.acs.org/doi/abs/10.1021/acs.jctc.5b01047)

